@@ -18,6 +18,10 @@ from pydmt.features.apt import FeatureApt
 from pydmt.features.npm import FeatureNpm
 from pydmt.features.venv import FeatureVenv
 from pydmt.features.reqs import FeatureReqs
+from pydmt.features.make import FeatureMake
+
+
+DISABLE = ".build.disable"
 
 
 def add_all_features(p):
@@ -35,6 +39,8 @@ def add_all_features(p):
     else:
         f = FeatureReqs()
         f.setup(p)
+    f = FeatureMake()
+    f.setup(p)
     f = FeatureYaml()
     f.setup(p)
 
@@ -70,6 +76,10 @@ def add_to_path():
     ],
 )
 def build():
+    if os.path.isfile(DISABLE):
+        if ConfigOutput.print_not:
+            print(f"build is disabled with file {DISABLE}")
+        return
     add_to_path()
 
     pylogconf.core.setup()
